==> haskell-insert-ordered-containers-0.2.5.3-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-5sDu2g7KmiN9dEFV8mZcS6
key:                  insert-ordered-containers-0.2.5.3-5sDu2g7KmiN9dEFV8mZcS6
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  974346165ef93a4eee658ca1b63f13e3
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-5sDu2g7KmiN9dEFV8mZcS6
depends:
    aeson-2.1.2.1-2383fjET7FWJSHJW4VQuW base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-5SoCNaysfySGuPwu0aljBu
    indexed-traversable-0.1.4-32owkfOBjPeHHjn6v5P4Ru
    lens-5.3.1-1UDi0CjALHfJ5iQ7KsOF6H
    optics-core-0.4.1.1-IVnhIKyneijuaO7AyI2qh
    optics-extra-0.4.2.1-8qIF7p2mKLpASog45TjSen
    semigroupoids-6.0.1-Ajxt1MUD1pH7gUEFlchfjE text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-AeV3HTkHtCc6BQ9fzLSSB8

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.5.3-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-FZcAVKSYbCW6DJP9tau6z9
key:                  insert-ordered-containers-0.2.5.3-FZcAVKSYbCW6DJP9tau6z9
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  43e4a2ab56ba38fc9300fa7b911e376f
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-FZcAVKSYbCW6DJP9tau6z9
depends:
    aeson-2.1.2.1-BWqAP5DPS0iMNSAJtMWSf base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    indexed-traversable-0.1.4-LyeF3yLPY26FCcc6uHtQva
    lens-5.3.1-L3T26fDKV8KAh84K9wN8lF
    optics-core-0.4.1.1-JeXa9GZybps8Nr07ZLXoCy
    optics-extra-0.4.2.1-IJodM6vwkcf2873LQskVMZ
    semigroupoids-6.0.1-6UDNhnrCcmB8qcD4TESfdi text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
